@@ -1,11 +1,25 @@
-# -*- coding: utf-8 -*-
+# Copyright (c) 2010-2013 by Yaco Sistemas <goinnn@gmail.com> or <pmartin@yaco.es>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this programe.  If not, see <http://www.gnu.org/licenses/>.
+
 import json
 
 from django import template
 from django.core.urlresolvers import reverse
 from django.template import Library, Variable
-from django.conf import settings
 
+from inplaceeditform import settings as inplace_settings
 from inplaceeditform.commons import get_adaptor_class, get_static_url, get_admin_static_url
 from inplaceeditform.tag_utils import RenderWithArgsAndKwargsNode, parse_args_kwargs
 
@@ -13,35 +27,38 @@ register = Library()
 
 
 def inplace_js(context, activate_inplaceedit=True, toolbar=False):
-    return context.update({
+    return {
         'STATIC_URL': get_static_url(),
         'ADMIN_MEDIA_PREFIX': get_admin_static_url(),
         'activate_inplaceedit': activate_inplaceedit,
-        'auto_save': json.dumps(getattr(settings, "INPLACEEDIT_AUTO_SAVE", False)),
-        'event': getattr(settings, "INPLACEEDIT_EVENT", "dblclick"),
-        'disable_click': json.dumps(getattr(settings, "INPLACEEDIT_DISABLE_CLICK", True)),
+        'auto_save': json.dumps(inplace_settings.INPLACEEDIT_AUTO_SAVE),
+        'event': inplace_settings.INPLACEEDIT_EVENT,
+        'disable_click': json.dumps(inplace_settings.INPLACEEDIT_DISABLE_CLICK),
         'toolbar': toolbar,
+        'enable_class': inplace_settings.INPLACE_ENABLE_CLASS,
+        'success_text': inplace_settings.INPLACEEDIT_SUCCESS_TEXT,
+        'unsaved_changes': inplace_settings.INPLACEEDIT_UNSAVED_TEXT,
         'inplace_get_field_url': reverse('inplace_get_field'),
         'inplace_save_url': reverse('inplace_save'),
-    })
+    }
 register.inclusion_tag("inplaceeditform/inplace_js.html", takes_context=True)(inplace_js)
 
 
 def inplace_css(context, toolbar=False):
-    return context.update({
+    return {
         'STATIC_URL': get_static_url(),
         'ADMIN_MEDIA_PREFIX': get_admin_static_url(),
         'toolbar': toolbar,
-    })
+    }
 register.inclusion_tag("inplaceeditform/inplace_css.html", takes_context=True)(inplace_css)
 
 
 def inplace_static(context):
-    return context.update({
+    return {
         'STATIC_URL': get_static_url(),
         'ADMIN_MEDIA_PREFIX': get_admin_static_url(),
         'toolbar': False,
-    })
+    }
 register.inclusion_tag("inplaceeditform/inplace_static.html", takes_context=True)(inplace_static)
 
 
@@ -52,11 +69,11 @@ register.inclusion_tag("inplaceeditform/inplace_static.html", takes_context=True
 
 
 def inplace_toolbar(context):
-    return context.update({
+    return {
         'STATIC_URL': get_static_url(),
         'ADMIN_MEDIA_PREFIX': get_admin_static_url(),
         'toolbar': True,
-    })
+    }
 register.inclusion_tag("inplaceeditform/inplace_static.html", takes_context=True)(inplace_toolbar)
 
 
